@@ -2,8 +2,8 @@
 hubspot3 module
 """
 from datetime import datetime, timedelta
+from typing import Any, Optional
 from hubspot3.error import HubspotBadConfig, HubspotNoConfig
-from typing import Any
 
 
 class Hubspot3UsageLimits:
@@ -34,13 +34,9 @@ class Hubspot3UsageLimits:
     def __str__(self) -> str:
         """string representation"""
         return (
-            "<Hubspot3UsageLimits: {}/{} ({}%) [reset in {}s, cached for {}s]>".format(
-                self.current_usage,
-                self.usage_limit,
-                self.calls_used,
-                self.until_reset,
-                self.until_cache_expire,
-            )
+            f"<Hubspot3UsageLimits: {self.current_usage}/{self.usage_limit}"
+            f"({self.calls_used}%) [reset in {self.until_reset}s, cached "
+            f"for {self.until_cache_expire}s]>"
         )
 
     def __repr__(self) -> str:
@@ -90,16 +86,16 @@ class Hubspot3:
 
     def __init__(
         self,
-        api_key: str = None,
-        access_token: str = None,
-        refresh_token: str = None,
-        client_id: str = None,
-        client_secret: str = None,
+        api_key: Optional[str] = None,
+        access_token: Optional[str] = None,
+        refresh_token: Optional[str] = None,
+        client_id: Optional[str] = None,
+        client_secret: Optional[str] = None,
         timeout: int = 10,
         api_base: str = "api.hubapi.com",
         debug: bool = False,
         disable_auth: bool = False,
-        **extra_options: Any
+        **extra_options: Any,
     ) -> None:
         """full client constructor"""
         self.api_key = api_key
