@@ -1,6 +1,7 @@
 """
 hubspot email events api
 """
+from typing import Optional
 from hubspot3.base import BaseClient
 from hubspot3.utils import get_log
 
@@ -20,7 +21,7 @@ class EmailEventsClient(BaseClient):
         self.log = get_log("hubspot3.email_events")
 
     def _get_path(self, subpath):
-        return "email/public/v{}/campaigns/{}".format(EMAIL_EVENTS_API_VERSION, subpath)
+        return f"email/public/v{EMAIL_EVENTS_API_VERSION}/campaigns/{subpath}"
 
     def get_all_campaigns_ids(self, **options):
         """
@@ -29,7 +30,7 @@ class EmailEventsClient(BaseClient):
         """
         return self._call("by-id", **options)
 
-    def get_campaign_data(self, campaign_id: int = None, **options):
+    def get_campaign_data(self, campaign_id: Optional[int] = None, **options):
         """
         Retrieve campaign data for a given campaign ID.
         :see: https://developers.hubspot.com/docs/methods/email/get_campaign_data
