@@ -1,9 +1,9 @@
 """
 hubspot engagements api
 """
+from typing import Dict, List
 from hubspot3.base import BaseClient
 from hubspot3.utils import get_log
-from typing import Dict, List
 
 
 ENGAGEMENTS_API_VERSION = "1"
@@ -21,15 +21,11 @@ class EngagementsClient(BaseClient):
 
     def _get_path(self, subpath: str) -> str:
         """get full subpath"""
-        return "engagements/v{}/{}".format(
-            self.options.get("version") or ENGAGEMENTS_API_VERSION, subpath
-        )
+        return f"engagements/v{self.options.get('version') or ENGAGEMENTS_API_VERSION}/{subpath}"
 
     def get(self, engagement_id, **options):
         """Get a HubSpot engagement."""
-        return self._call(
-            "engagements/{}".format(engagement_id), method="GET", **options
-        )
+        return self._call(f"engagements/{engagement_id}", method="GET", **options)
 
     def get_associated(self, object_type, object_id, **options) -> List[Dict]:
         """
@@ -43,10 +39,10 @@ class EngagementsClient(BaseClient):
         offset = 0
         while not finished:
             batch = self._call(
-                "engagements/associated/{}/{}/paged".format(object_type, object_id),
+                f"engagements/associated/{object_type}/{object_id}/paged",
                 method="GET",
                 params={"limit": query_limit, "offset": offset},
-                **options
+                **options,
             )
             output.extend(batch["results"])
             finished = not batch["hasMore"]
@@ -60,15 +56,11 @@ class EngagementsClient(BaseClient):
 
     def update(self, key, data=None, **options):
         data = data or {}
-        return self._call(
-            "engagements/{}".format(key), data=data, method="PUT", **options
-        )
+        return self._call(f"engagements/{key}", data=data, method="PUT", **options)
 
     def patch(self, key, data=None, **options):
         data = data or {}
-        return self._call(
-            "engagements/{}".format(key), data=data, method="PATCH", **options
-        )
+        return self._call(f"engagements/{key}", data=data, method="PATCH", **options)
 
     def get_all(self, **options) -> List[Dict]:
         """get all engagements"""
@@ -81,7 +73,7 @@ class EngagementsClient(BaseClient):
                 "engagements/paged",
                 method="GET",
                 params={"limit": query_limit, "offset": offset},
-                **options
+                **options,
             )
             output.extend(batch["results"])
             finished = not batch["hasMore"]
@@ -100,7 +92,7 @@ class EngagementsClient(BaseClient):
                 "engagements/recent/modified",
                 method="GET",
                 params={"limit": query_limit, "offset": offset, "since": since},
-                **options
+                **options,
             )
             output.extend(batch["results"])
             finished = not batch["hasMore"]
