@@ -1,9 +1,11 @@
 """
 hubspot workflows api
 """
+from typing import Optional
 from hubspot3.base import BaseClient
 from hubspot3.utils import get_log
 
+
 WORKFLOWS_API_VERSION = "3"
 
 
@@ -19,7 +21,7 @@ class WorkflowsClient(BaseClient):
         self.log = get_log("hubspot3.workflows")
 
     def _get_path(self, subpath):
-        return "automation/v{}/{}".format(WORKFLOWS_API_VERSION, subpath)
+        return f"automation/v{WORKFLOWS_API_VERSION}/{subpath}"
 
     def get_all_workflow_ids(self, **options):
         """
@@ -28,11 +30,11 @@ class WorkflowsClient(BaseClient):
         """
         return self._call("workflows", **options)
 
-    def get_workflow_by_id(self, workflow_id: int = None, **options):
+    def get_workflow_by_id(self, workflow_id: Optional[int] = None, **options):
         """
         Get workflow specified by ID
         :see: https://developers.hubspot.com/docs/methods/workflows/v3/get_workflow
         """
         if workflow_id is not None:
-            return self._call("workflows/{}".format(workflow_id))
+            return self._call(f"workflows/{workflow_id}")
         return None
